@@ -5,10 +5,14 @@ use 5.008;
 use strict;
 use warnings;
 
-use CPAN::Access::AdHoc::Util qw{ __attr :carp };
+use CPAN::Access::AdHoc::Util qw{
+    __attr __expand_distribution_path __guess_media_type :carp
+};
+use CPAN::Meta ();
+use HTTP::Response ();
 use Module::Pluggable::Object;
 
-our $VERSION = '0.000_04';
+our $VERSION = '0.000_06';
 
 # Note that this can be called as a mutator, but the mutator
 # functionality is private to the invocant's class.
@@ -42,6 +46,20 @@ sub get_item_mtime {
     __weep( 'The get_item_mtime() method must be overridden' );
 }
 
+sub guess_media_type {
+    my ( $class, $resp, $path ) = @_;
+
+    __whinge( join ' ',
+	'CPAN::Access::AdHoc::Archive::guess_media_type() is',
+	'deprecated in favor of',
+	'CPAN::Access::AdHoc::Util::__guess_media_type()'
+    );
+
+    __guess_media_type( $resp, $path );
+
+    return;
+}
+
 {
     my @archivers = Module::Pluggable::Object->new(
 	search_path	=> 'CPAN::Access::AdHoc::Archive',
@@ -50,11 +68,19 @@ sub get_item_mtime {
     )->plugins();
 
     sub handle_http_response {
+	__whinge( join ' ',
+	    'handle_http_response() is deprecated in favor of',
+	    '__handle_http_response()',
+	);
+	goto &__handle_http_response;
+    }
+
+    sub __handle_http_response {
 	my ( $class, $resp ) = @_;
 
 	foreach my $archiver ( @archivers ) {
 	    my $archive;
-	    defined( $archive = $archiver->handle_http_response( $resp ) )
+	    defined( $archive = $archiver->__handle_http_response( $resp ) )
 		and return $archive;
 	}
 
@@ -112,6 +138,41 @@ sub path {
     }
 }
 
+sub wrap_archive {
+    my ( $self, $fn, $author_dir ) = @_;
+    -f $fn
+	or __wail( "File $fn not found" );
+    my $content;
+    {
+	local $/ = undef;
+	open my $fh, '<', $fn or __wail( "Unable to open $fn: $!" );
+	binmode $fh;
+	$content = <$fh>;
+	close $fh;
+    }
+    my $path;
+    if ( defined $author_dir ) {
+	my $author_path = __expand_distribution_path( $author_dir );
+	$author_path =~ s{ / \z }{}smx;
+	$path = join '/', 'authors/id', $author_path,
+	    ( File::Spec->splitpath( $fn ) )[2];
+    } else {
+	my ( $dev, $dir, $base ) = File::Spec->splitpath( $fn );
+	my @dirs = grep { $_ ne '' } File::Spec->splitdir( $dir );
+	@dirs
+	    or @dirs = grep { $_ ne '' } Cwd::cwd();
+	if ( @dirs ) {
+	    $path = join '/', 'authors/id', __expand_distribution_path(
+		"$dirs[-1]/$base" );
+	} else {
+	    $path = $fn;
+	}
+    }
+    my $resp = HTTP::Response->new( 200, 'OK', undef, $content );
+    __guess_media_type( $resp, $path );
+    return $self->__handle_http_response( $resp );
+}
+
 1;
 
 __END__
@@ -124,6 +185,27 @@ CPAN::Access::AdHoc::Archive - Common archive functionality for CPAN::Access::Ad
 
 This class is not intended to be used directly.
 
+=head1 NOTICE
+
+Effective with version 0.000_06:
+
+* Static method C<__guess_media_type()> is deprecated. The code has been
+moved to C<CPAN::Access::AdHoc::Util> as subroutine
+C<__guess_media_type()>, which is private to the C<CPAN-Access-AdHoc>
+package.
+
+* Static method C<handle_http_response()> is deprecated. The code has
+been renamed to C<__handle_http_response()>, and is considered private
+to the C<CPAN-Access-AdHoc> package.
+
+Because the deprecated methods have never been in a production release,
+they will be removed a week after the publication of version 0.000_06.
+
+I have never been real happy about exposing these in the public
+interface, and with the writing of
+C<< CPAN::Access::AdHoc::Archive->wrap_archive() >>, the need to expose
+them appears to me to have gone away.
+
 =head1 DESCRIPTION
 
 This class provides common functionality needed by the accessors for the
@@ -239,27 +321,49 @@ This method returns the modification time of the named item in the
 archive. The name of the item is specified relative to
 C<< $arc->base_directory() >>.
 
+=head3 guess_media_type
+
+ CPAN::Access::AdHoc::Archive->guess_media_type( $resp, $path );
+
+This static method is deprecated. It is a wrapper for
+C<CPAN::Access::AdHoc::__guess_media_type()>.
+
+Because this method has never appeared in a production release, it will
+be removed a week after the next release, which will be a development
+release.
+
 =head3 handle_http_response
 
-This static method takes as its argument an
-L<HTTP::Response|HTTP::Response> object. If this method determines that
-it can handle the response object, it does so, returning the
-C<CPAN::Access::AdHoc::Archive> object derived from the content of the
-L<HTTP::Response|HTTP::Response> object. Otherwise, it simply returns.
+This static method is deprecated in favor of __handle_http_response().
+
+=head3 __handle_http_response
+
+This static method is private to the C<CPAN-Access-AdHoc> package.
+
+This method takes as its argument an L<HTTP::Response|HTTP::Response>
+object. If this method determines that it can handle the response
+object, it does so, returning the C<CPAN::Access::AdHoc::Archive> object
+derived from the content of the L<HTTP::Response|HTTP::Response> object.
+Otherwise, it simply returns.
 
 The method can do anything it wants to evaluate its argument, but
 typically it examines the C<Content-Type>, C<Content-Encoding>, and
 C<Content-Location> headers. The expected values of these headers are
 those loaded by C<LWP::MediaTypes::guess_media_type()>.
 
-For this class (i.e. C<CPAN::Access::AdHoc::Archive>, the method simply
-calls C<handle_http_response()> on all the
+For this class (i.e. C<CPAN::Access::AdHoc::Archive>), the method simply
+calls C<__handle_http_response()> on all the
 C<CPAN::Access::AdHoc::Archive::*> classes until one chooses to handle
 the L<HTTP::Response|HTTP::Response> object by returning a
 C<CPAN::Access::AdHoc::Archive> object. If none of the subclasses
 handles the L<HTTP::Response|HTTP::Response> object, nothing is
 returned.
 
+The whole C<guess_media_type()>/C<__handle_http_response()> thing seems
+like a crock to me, but I have not been able to think of anything
+better. If they make it into a production release, they B<will> go
+through a deprecation cycle.
+
 =head3 item_present
 
  $arc->item_present( 'Build.PL' )
@@ -282,6 +386,17 @@ in that order. If neither is present, or neither contains valid metadata
 as determined by L<CPAN::Meta|CPAN::Meta>, nothing is returned -- this
 method makes no further effort to establish what the metadata are.
 
+=head2 wrap_archive
+
+ my $archive = CPAN::Access::AdHoc::Archive->wrap_archive(
+     'foo/MyDistrib-0.001.tar.gz', 'MYCPANID' );
+
+This method (either normal or static) makes a
+C<CPAN::Access::AdHoc::Archive> object out of a local file, and returns
+it. The second argument is the CPAN ID to assign to the archive. If this
+is omitted the directory the file is in will provide the CPAN ID, which
+is probably not what you want.
+
 =head1 SUPPORT
 
 Support is by the author. Please file bug reports at
