@@ -15,7 +15,7 @@ use IO::File ();
 use IO::Uncompress::Bunzip2 ();
 use IO::Uncompress::Gunzip ();
 
-our $VERSION = '0.000_04';
+our $VERSION = '0.000_06';
 
 my %decode = (
     gzip	=> sub {
@@ -150,6 +150,14 @@ sub get_item_mtime {
     my %handled = map { $_ => 1 } qw{ application/octet-stream };
 
     sub handle_http_response {
+	__whinge( join ' ',
+	    'handle_http_response() is deprecated in favor of',
+	    '__handle_http_response()',
+	);
+	goto &__handle_http_response;
+    }
+
+    sub __handle_http_response {
 	my ( $class, $rslt ) = @_;
 
 	my $content_type = $rslt->header( 'Content-Type' );
