@@ -12,7 +12,7 @@ use CPAN::Access::AdHoc::Util qw{ :carp };
 use File::Spec::Unix ();
 use IO::File ();
 
-our $VERSION = '0.000_04';
+our $VERSION = '0.000_06';
 
 {
 
@@ -106,6 +106,14 @@ sub get_item_mtime {
     my %handled = map { $_ => 1 } qw{ application/zip };
 
     sub handle_http_response {
+	__whinge( join ' ',
+	    'handle_http_response() is deprecated in favor of',
+	    '__handle_http_response()',
+	);
+	goto &__handle_http_response;
+    }
+
+    sub __handle_http_response {
 	my ( $class, $rslt ) = @_;
 
 	$handled{ $rslt->header( 'Content-Type' ) }
@@ -175,7 +183,8 @@ C<CPAN-Access-AdHoc> package.
 =head1 METHODS
 
 This class supports the following public methods over and above those
-supported by its superclass:
+supported by its superclass, or with functionality over and above that
+of the superclass.
 
 =head2 new
 
@@ -205,6 +214,13 @@ argument may only be specified as C<undef>.
 This method returns the content of the named item in the archive. It is
 simply a wrapper for C<< Archive::Zip->memberNamed()->contents() >>.
 
+=head2 get_item_mtime
+
+Unfortunately, Zip file entry time stamps are in local time, and there
+is no zone information included. This means that unless this is called
+in the same time zone in which the Zip entry was created you get the
+wrong time. In other words, the results of this method are useless.
+
 =head2 list_contents
 
 This method lists the contents of the archive. It is simply a wrapper
