@@ -5,19 +5,21 @@ use 5.008;
 use strict;
 use warnings;
 
-use File::Find;
-use File::Spec;
-
 use base qw{ Exporter };
 
-our @EXPORT_OK = qw{ __attr __load __whinge __wail __weep };
+use LWP::MediaTypes ();
+
+our @EXPORT_OK = qw{
+    __attr __expand_distribution_path __guess_media_type
+    __load __whinge __wail __weep
+};
 
 our %EXPORT_TAGS = (
     all	=> [ @EXPORT_OK ],
     carp => [ qw{ __whinge __wail __weep } ],
 );
 
-our $VERSION = '0.000_04';
+our $VERSION = '0.000_06';
 
 sub __attr {
     my ( $self ) = @_;
@@ -25,6 +27,36 @@ sub __attr {
     return ( $self->{$name_space} ||= {} );
 }
 
+sub __expand_distribution_path {
+    my ( $path ) = @_;
+    $path =~ m{ \A ( [^/] ) / ( \1 [^/] ) / ( \2 [^/]* ) }smx
+	and return $path;
+    $path =~ m< \A ( [^/]{2} ) / ( \1 [^/]* ) >smx
+	and return join '/', substr( $1, 0, 1 ), $path;
+    $path =~ m< \A ( [^/]+ ) >smx
+	or __wail( "Invalid distribution path '$path'" );
+    return join '/', substr( $1, 0, 1 ),
+	substr( $1, 0, 2 ), $path;
+}
+
+sub __guess_media_type {
+    my ( $resp, $path ) = @_;
+
+    if ( defined $path ) {
+	$resp->header( 'Content-Location' => $path );
+    } else {
+	defined( $path = $resp->header( 'Content-Location' ) )
+	    or __wail( 'No path provided, and none in Content-Location' );
+    }
+
+    # LWP::MediaTypes needs help with some paths.
+    $path =~ s/ [.] tgz \z /.tar.gz/smxi;
+
+    LWP::MediaTypes::guess_media_type( $path, $resp );
+
+    return;
+}
+
 sub __load {
     my ( @args ) = @_;
     foreach my $module ( @args ) {
@@ -104,6 +136,35 @@ This subroutine/method returns the hash element of its argument which is
 named after the caller's name space. This element is initialized to an
 empty hash if necessary.
 
+=head2 __expand_distribution_path
+
+This subroutine takes as its argument a putative distribution path
+relative to the F<authors/id/> directory. If it does not begin with the
+two levels of directory that are derived from the author name, these are
+added. The expanded path is returned.
+
+=head3 __guess_media_type
+
+ __guess_media_type( $resp, $path );
+
+This subroutine guesses the media type and encoding.
+
+The first argument is an L<HTTP::Response|HTTP::Response> object such as
+would have been returned by a successful fetch of the data.
+
+The second argument is optional, and is the URL or path used to fetch
+the data. If the second argument is defined, it sets the
+C<Content-Location> header in C<$resp>.  If C<$path> is not defined, it
+defaults to C<< $resp->header( 'Content-Location' ) >>, and an exception
+is thrown if there is none.
+
+The method loads the C<Content-Type> and C<Content-Encoding> headers of
+the C<$resp> object with its best guess at what they are. Nothing is
+returned.
+
+Note that the arguments are reversed from
+C<LWP::MediaTypes::guess_media_type()>.
+
 =head2 __load
 
 This subroutine takes as its arguments one or more module names, and
